@@ -39,7 +39,6 @@
  * "find"
  * "find-again"
  * "find-and-replace"
- * "html-mode"		(toggle)
  * "indent"
  * "insert-html-file"
  * "insert-smiley-1"
@@ -58,6 +57,8 @@
  * "justify-center"	(radio)
  * "justify-left"	(radio)
  * "justify-right"	(radio)
+ * "mode-html"		(radio)
+ * "mode-plain"		(radio)
  * "paste"
  * "paste-quote"
  * "redo"
@@ -86,13 +87,13 @@
  * Core Actions (HTML Only)
  * ------------------------
  * "bold"		(toggle)
- * "properties-page"
  * "insert-image"
  * "insert-link"
  * "insert-rule"
  * "insert-table"
  * "italic"		(toggle)
  * "monospaced"		(toggle)
+ * "properties-page"
  * "size-minus-one"	(radio)
  * "size-minus-two"	(radio)
  * "size-plus-four"	(radio)
@@ -617,69 +618,6 @@ action_find_and_replace_cb (GtkAction *action,
 		FALSE, replace_ask_cb, editor);
 }
 
-static void
-action_html_mode_cb (GtkToggleAction *action,
-                     GtkhtmlEditor *editor)
-{
-	GtkActionGroup *action_group;
-	HTMLPainter *new_painter;
-	HTMLPainter *old_painter;
-	GtkHTML *html;
-	gboolean active;
-
-	html = gtkhtml_editor_get_html (editor);
-	active = gtk_toggle_action_get_active (action);
-
-	action_group = editor->priv->html_actions;
-	gtk_action_group_set_sensitive (action_group, active);
-
-	action_group = editor->priv->html_context_actions;
-	gtk_action_group_set_visible (action_group, active);
-
-        gtk_widget_set_sensitive (editor->priv->color_combo_box, active);
-
-	/* Certain paragraph styles are HTML-only. */
-	gtk_action_set_sensitive (ACTION (STYLE_H1), active);
-	gtk_action_set_sensitive (ACTION (STYLE_H2), active);
-	gtk_action_set_sensitive (ACTION (STYLE_H3), active);
-	gtk_action_set_sensitive (ACTION (STYLE_H4), active);
-	gtk_action_set_sensitive (ACTION (STYLE_H5), active);
-	gtk_action_set_sensitive (ACTION (STYLE_H6), active);
-	gtk_action_set_sensitive (ACTION (STYLE_ADDRESS), active);
-
-	/* Swap painters. */
-
-	if (active) {
-		new_painter = editor->priv->html_painter;
-		old_painter = editor->priv->plain_painter;
-	} else {
-		new_painter = editor->priv->plain_painter;
-		old_painter = editor->priv->html_painter;
-	}
-
-	/* Might be true during initialization. */
-	if (html->engine->painter == new_painter)
-		return;
-
-	html_gdk_painter_unrealize (HTML_GDK_PAINTER (old_painter));
-	if (html->engine->window != NULL)
-		html_gdk_painter_realize (
-			HTML_GDK_PAINTER (new_painter),
-			html->engine->window);
-
-	html_font_manager_set_default (
-		&new_painter->font_manager,
-		old_painter->font_manager.variable.face,
-		old_painter->font_manager.fixed.face,
-		old_painter->font_manager.var_size,
-		old_painter->font_manager.var_points,
-		old_painter->font_manager.fix_size,
-		old_painter->font_manager.fix_points);
-
-	html_engine_set_painter (html->engine, new_painter);
-	html_engine_schedule_redraw (html->engine);
-}
-
 static void
 action_indent_cb (GtkAction *action,
                   GtkhtmlEditor *editor)
@@ -961,6 +899,77 @@ action_language_cb (GtkToggleAction *action,
 	gtk_action_set_sensitive (ACTION (SPELL_CHECK), length > 0);
 }
 
+static void
+action_mode_cb (GtkRadioAction *action,
+                GtkRadioAction *current,
+                GtkhtmlEditor *editor)
+{
+	GtkActionGroup *action_group;
+	HTMLPainter *new_painter;
+	HTMLPainter *old_painter;
+	GtkHTML *html;
+	EditorMode mode;
+	gboolean html_mode;
+
+	html = gtkhtml_editor_get_html (editor);
+	mode = gtk_radio_action_get_current_value (current);
+	html_mode = (mode == EDITOR_MODE_HTML);
+
+	action_group = editor->priv->html_actions;
+	gtk_action_group_set_sensitive (action_group, html_mode);
+
+	action_group = editor->priv->html_context_actions;
+	gtk_action_group_set_visible (action_group, html_mode);
+
+        gtk_widget_set_sensitive (editor->priv->color_combo_box, html_mode);
+
+	if (html_mode)
+		gtk_widget_show (editor->priv->html_toolbar);
+	else
+		gtk_widget_hide (editor->priv->html_toolbar);
+
+	/* Certain paragraph styles are HTML-only. */
+	gtk_action_set_sensitive (ACTION (STYLE_H1), html_mode);
+	gtk_action_set_sensitive (ACTION (STYLE_H2), html_mode);
+	gtk_action_set_sensitive (ACTION (STYLE_H3), html_mode);
+	gtk_action_set_sensitive (ACTION (STYLE_H4), html_mode);
+	gtk_action_set_sensitive (ACTION (STYLE_H5), html_mode);
+	gtk_action_set_sensitive (ACTION (STYLE_H6), html_mode);
+	gtk_action_set_sensitive (ACTION (STYLE_ADDRESS), html_mode);
+
+	/* Swap painters. */
+
+	if (html_mode) {
+		new_painter = editor->priv->html_painter;
+		old_painter = editor->priv->plain_painter;
+	} else {
+		new_painter = editor->priv->plain_painter;
+		old_painter = editor->priv->html_painter;
+	}
+
+	/* Might be true during initialization. */
+	if (html->engine->painter == new_painter)
+		return;
+
+	html_gdk_painter_unrealize (HTML_GDK_PAINTER (old_painter));
+	if (html->engine->window != NULL)
+		html_gdk_painter_realize (
+			HTML_GDK_PAINTER (new_painter),
+			html->engine->window);
+
+	html_font_manager_set_default (
+		&new_painter->font_manager,
+		old_painter->font_manager.variable.face,
+		old_painter->font_manager.fixed.face,
+		old_painter->font_manager.var_size,
+		old_painter->font_manager.var_points,
+		old_painter->font_manager.fix_size,
+		old_painter->font_manager.fix_points);
+
+	html_engine_set_painter (html->engine, new_painter);
+	html_engine_schedule_redraw (html->engine);
+}
+
 static void
 action_monospaced_cb (GtkToggleAction *action,
                       GtkhtmlEditor *editor)
@@ -1321,8 +1330,8 @@ static GtkActionEntry core_entries[] = {
 	{ "indent",
 	  GTK_STOCK_INDENT,
 	  N_("_Increase Indent"),
-	  "<Control>bracketleft",
-	  NULL,
+	  "<Control>bracketright",
+	  N_("Increase Indent"),
 	  G_CALLBACK (action_indent_cb) },
 
 	{ "insert-html-file",
@@ -1524,14 +1533,14 @@ static GtkActionEntry core_entries[] = {
 	{ "unindent",
 	  GTK_STOCK_UNINDENT,
 	  N_("_Decrease Indent"),
-	  "<Control>bracketright",
-	  NULL,
+	  "<Control>bracketleft",
+	  N_("Decrease Indent"),
 	  G_CALLBACK (action_unindent_cb) },
 
 	{ "wrap-lines",
 	  NULL,
 	  N_("_Wrap Lines"),
-	  "<Control>l",
+	  "<Control>backslash",
 	  NULL,
 	  G_CALLBACK (action_wrap_lines_cb) },
 
@@ -1553,7 +1562,7 @@ static GtkActionEntry core_entries[] = {
 
 	{ "format-menu",
 	  NULL,
-	  N_("_Format"),
+	  N_("For_mat"),
 	  NULL,
 	  NULL,
 	  NULL },
@@ -1601,41 +1610,47 @@ static GtkActionEntry core_entries[] = {
 	  NULL }
 };
 
-static GtkToggleActionEntry core_toggle_entries[] = {
-
-	{ "html-mode",
-	  NULL,
-	  N_("_HTML Mode"),
-	  NULL,
-	  NULL,
-	  G_CALLBACK (action_html_mode_cb),
-	  TRUE },
-};
-
 static GtkRadioActionEntry core_justify_entries[] = {
 
 	{ "justify-center",
 	  GTK_STOCK_JUSTIFY_CENTER,
 	  N_("_Center"),
-	  NULL,
-	  NULL,
+	  "<Control>e",
+	  N_("Center Alignment"),
 	  GTK_HTML_PARAGRAPH_ALIGNMENT_CENTER },
 
 	{ "justify-left",
 	  GTK_STOCK_JUSTIFY_LEFT,
 	  N_("_Left"),
-	  NULL,
-	  NULL,
+	  "<Control>l",
+	  N_("Left Alignment"),
 	  GTK_HTML_PARAGRAPH_ALIGNMENT_LEFT },
 
 	{ "justify-right",
 	  GTK_STOCK_JUSTIFY_RIGHT,
 	  N_("_Right"),
-	  NULL,
-	  NULL,
+	  "<Control>r",
+	  N_("Right Alignment"),
 	  GTK_HTML_PARAGRAPH_ALIGNMENT_RIGHT }
 };
 
+static GtkRadioActionEntry core_mode_entries[] = {
+
+	{ "mode-html",
+	  NULL,
+	  N_("_HTML"),
+	  NULL,
+	  N_("HTML editing mode"),
+	  EDITOR_MODE_HTML },
+
+	{ "mode-plain",
+	  NULL,
+	  N_("Plain _Text"),
+	  NULL,
+	  N_("Plain text editing mode"),
+	  EDITOR_MODE_TEXT }
+};
+
 static GtkRadioActionEntry core_style_entries[] = {
 
 	{ "style-normal",
@@ -1742,28 +1757,28 @@ static GtkActionEntry html_entries[] = {
 	  "insert-image",
 	  N_("_Image..."),
 	  NULL,
-	  NULL,
+	  N_("Insert Image"),
 	  G_CALLBACK (action_insert_image_cb) },
 
 	{ "insert-link",
 	  "insert-link",
 	  N_("_Link..."),
 	  NULL,
-	  NULL,
+	  N_("Insert Link"),
 	  G_CALLBACK (action_insert_link_cb) },
 
 	{ "insert-rule",
 	  "stock_insert-rule",
 	  N_("_Rule..."),
 	  NULL,
-	  NULL,
+	  N_("Insert Rule"),
 	  G_CALLBACK (action_insert_rule_cb) },
 
 	{ "insert-table",
 	  "stock_insert-table",
 	  N_("_Table..."),
 	  NULL,
-	  NULL,
+	  N_("Insert Table"),
 	  G_CALLBACK (action_insert_table_cb) },
 
 	{ "properties-cell",
@@ -1831,7 +1846,7 @@ static GtkToggleActionEntry html_toggle_entries[] = {
 	  GTK_STOCK_BOLD,
 	  N_("_Bold"),
 	  "<Control>b",
-	  NULL,
+	  N_("Bold"),
 	  G_CALLBACK (action_bold_cb),
 	  FALSE },
 
@@ -1839,7 +1854,7 @@ static GtkToggleActionEntry html_toggle_entries[] = {
 	  GTK_STOCK_ITALIC,
 	  N_("_Italic"),
 	  "<Control>i",
-	  NULL,
+	  N_("Italic"),
 	  G_CALLBACK (action_italic_cb),
 	  FALSE },
 
@@ -1847,7 +1862,7 @@ static GtkToggleActionEntry html_toggle_entries[] = {
 	  "stock_text-monospaced",
 	  N_("_Plain Text"),
 	  "<Control>t",
-	  NULL,
+	  N_("Plain Text"),
 	  G_CALLBACK (action_monospaced_cb),
 	  FALSE },
 
@@ -1855,7 +1870,7 @@ static GtkToggleActionEntry html_toggle_entries[] = {
 	  GTK_STOCK_STRIKETHROUGH,
 	  N_("_Strikethrough"),
 	  NULL,
-	  NULL,
+	  N_("Strikethrough"),
 	  G_CALLBACK (action_strikethrough_cb),
 	  FALSE },
 
@@ -1863,7 +1878,7 @@ static GtkToggleActionEntry html_toggle_entries[] = {
 	  GTK_STOCK_UNDERLINE,
 	  N_("_Underline"),
 	  "<Control>u",
-	  NULL,
+	  N_("Underline"),
 	  G_CALLBACK (action_underline_cb),
 	  FALSE }
 };
@@ -2265,26 +2280,29 @@ gtkhtml_editor_actions_init (GtkhtmlEditor *editor)
 {
 	GtkActionGroup *action_group;
 	GtkUIManager *manager;
+	const gchar *domain;
 
 	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
 
 	manager = gtkhtml_editor_get_ui_manager (editor);
+	domain = GETTEXT_PACKAGE;
 
 	/* Core Actions */
 	action_group = editor->priv->core_actions;
-	gtk_action_group_set_translation_domain (
-		action_group, GETTEXT_PACKAGE);
+	gtk_action_group_set_translation_domain (action_group, domain);
 	gtk_action_group_add_actions (
 		action_group, core_entries,
 		G_N_ELEMENTS (core_entries), editor);
-	gtk_action_group_add_toggle_actions (
-		action_group, core_toggle_entries,
-		G_N_ELEMENTS (core_toggle_entries), editor);
 	gtk_action_group_add_radio_actions (
 		action_group, core_justify_entries,
 		G_N_ELEMENTS (core_justify_entries),
 		GTK_HTML_PARAGRAPH_ALIGNMENT_LEFT,
 		G_CALLBACK (action_justify_cb), editor);
+	gtk_action_group_add_radio_actions (
+		action_group, core_mode_entries,
+		G_N_ELEMENTS (core_mode_entries),
+		EDITOR_MODE_HTML,
+		G_CALLBACK (action_mode_cb), editor);
 	gtk_action_group_add_radio_actions (
 		action_group, core_style_entries,
 		G_N_ELEMENTS (core_style_entries),
@@ -2294,8 +2312,7 @@ gtkhtml_editor_actions_init (GtkhtmlEditor *editor)
 
 	/* Core Actions (HTML only) */
 	action_group = editor->priv->html_actions;
-	gtk_action_group_set_translation_domain (
-		action_group, GETTEXT_PACKAGE);
+	gtk_action_group_set_translation_domain (action_group, domain);
 	gtk_action_group_add_actions (
 		action_group, html_entries,
 		G_N_ELEMENTS (html_entries), editor);
@@ -2311,8 +2328,7 @@ gtkhtml_editor_actions_init (GtkhtmlEditor *editor)
 
 	/* Context Menu Actions */
 	action_group = editor->priv->context_actions;
-	gtk_action_group_set_translation_domain (
-		action_group, GETTEXT_PACKAGE);
+	gtk_action_group_set_translation_domain (action_group, domain);
 	gtk_action_group_add_actions (
 		action_group, context_entries,
 		G_N_ELEMENTS (context_entries), editor);
@@ -2320,8 +2336,7 @@ gtkhtml_editor_actions_init (GtkhtmlEditor *editor)
 
 	/* Context Menu Actions (HTML only) */
 	action_group = editor->priv->html_context_actions;
-	gtk_action_group_set_translation_domain (
-		action_group, GETTEXT_PACKAGE);
+	gtk_action_group_set_translation_domain (action_group, domain);
 	gtk_action_group_add_actions (
 		action_group, html_context_entries,
 		G_N_ELEMENTS (html_context_entries), editor);
@@ -2329,8 +2344,7 @@ gtkhtml_editor_actions_init (GtkhtmlEditor *editor)
 
 	/* Context Menu Actions (spell check only) */
 	action_group = editor->priv->spell_check_actions;
-	gtk_action_group_set_translation_domain (
-		action_group, GETTEXT_PACKAGE);
+	gtk_action_group_set_translation_domain (action_group, domain);
 	gtk_action_group_add_actions (
 		action_group, spell_context_entries,
 		G_N_ELEMENTS (spell_context_entries), editor);
