@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _POPUP_H_
@@ -27,6 +27,7 @@
 
 gint  popup_show            (GtkHTMLControlData *cd,
 			     GdkEventButton     *event);
+gint  popup_show_at_cursor  (GtkHTMLControlData *cd);
 void  property_dialog_show  (GtkHTMLControlData *cd);
 
 #endif
